@@ -10,10 +10,9 @@ def put_repos_in_queue(
     queue_lock: threading.Lock,
     repo_queue: queue.Queue,
 ) -> None:
-    """
-    Puts into the queue repositories obtained from a dictionary
-    Each element of the json_response is a dictionary containing the GitHub response with repository information.
-    """
+    """Puts into the queue repositories obtained from a dictionary Each element
+    of the json_response is a dictionary containing the GitHub response with
+    repository information."""
     queue_lock.acquire()
     for repo_number in range(len(json_response)):
         repo_queue.put(
